@@ -1,8 +1,4 @@
 """Project default for pytest"""
-from astropy.tests.helper import enable_deprecations_as_exceptions
-
-# Uncomment the following line to treat all DeprecationWarnings as exceptions
-enable_deprecations_as_exceptions()
 
 
 # Utilities to support command line passing of arguments to test_randomlist.py
