@@ -32,6 +32,7 @@ aspects of each of the processing steps.
 """
 import os
 import sys
+import logging
 
 from stsci.tools import teal, logutil, textutil
 
@@ -44,7 +45,7 @@ from . import sky
 from . import staticMask
 from . import util
 from . import wcs_functions
-from .version import *
+from . import __version__
 
 
 __taskname__ = "astrodrizzle"
@@ -70,7 +71,7 @@ def AstroDrizzle(input=None, mdriztab=False, editpars=False, configobj=None,
             configobj = teal.load(__taskname__)
         else:
             if not os.path.exists(configobj):
-                raise RuntimeError('Cannot find .cfg file: '+configobj)
+                raise RuntimeError('Cannot find .cfg file: ' + configobj)
             configobj = teal.load(configobj, strict=False)
     elif configobj is None:
         # load 'astrodrizzle' parameter defaults as described in the docs:
@@ -82,7 +83,7 @@ def AstroDrizzle(input=None, mdriztab=False, editpars=False, configobj=None,
         raise TypeError("AstroDrizzle() needs either 'input' or "
                         "'configobj' arguments")
 
-    if 'updatewcs' in input_dict: # user trying to explicitly turn on updatewcs
+    if 'updatewcs' in input_dict:  # user trying to explicitly turn on updatewcs
         configobj['updatewcs'] = input_dict['updatewcs']
         del input_dict['updatewcs']
 
@@ -118,7 +119,7 @@ def AstroDrizzle(input=None, mdriztab=False, editpars=False, configobj=None,
         run(configObj, wcsmap=wcsmap)
 
 ##############################
-##  Interfaces used by TEAL ##
+#   Interfaces used by TEAL  #
 ##############################
 @util.with_logging
 def run(configobj, wcsmap=None):
@@ -159,11 +160,17 @@ def run(configobj, wcsmap=None):
         def_logname = None
         return
 
+    # Build name of output trailer file
+    logging_handlers = logging.getLogger().handlers
+    log_name = [lh.name for lh in logging_handlers if lh.level > 0]
+    logfile = log_name[0] if log_name else "{}.tra".format(def_logname)
+    print("AstroDrizzle log file: {}".format(logfile))
+
     clean = configobj['STATE OF INPUT FILES']['clean']
     procSteps = util.ProcSteps()
 
-    print("AstroDrizzle Version {:s} ({:s}) started at: {:s}\n"
-          .format(__version__, __version_date__, util._ptime()[0]))
+    print("AstroDrizzle Version {:s} started at: {:s}\n"
+          .format(__version__, util._ptime()[0]))
     util.print_pkg_versions(log=log)
 
     log.debug('')
@@ -196,33 +203,35 @@ def run(configobj, wcsmap=None):
         util.printParams(configobj, log=log)
 
         # Call rest of MD steps...
-        #create static masks for each image
+        # create static masks for each image
         staticMask.createStaticMask(imgObjList, configobj,
                                     procSteps=procSteps)
 
-        #subtract the sky
+        # subtract the sky
         sky.subtractSky(imgObjList, configobj, procSteps=procSteps)
 
 #       _dbg_dump_virtual_outputs(imgObjList)
 
-        #drizzle to separate images
+        # drizzle to separate images
         adrizzle.drizSeparate(imgObjList, outwcs, configobj, wcsmap=wcsmap,
+                              logfile=logfile,
                               procSteps=procSteps)
 
 #       _dbg_dump_virtual_outputs(imgObjList)
 
-        #create the median images from the driz sep images
+        # create the median images from the driz sep images
         createMedian.createMedian(imgObjList, configobj, procSteps=procSteps)
 
-        #blot the images back to the original reference frame
+        # blot the images back to the original reference frame
         ablot.runBlot(imgObjList, outwcs, configobj, wcsmap=wcsmap,
                       procSteps=procSteps)
 
-        #look for cosmic rays
+        # look for cosmic rays
         drizCR.rundrizCR(imgObjList, configobj, procSteps=procSteps)
 
-        #Make your final drizzled image
+        # Make your final drizzled image
         adrizzle.drizFinal(imgObjList, outwcs, configobj, wcsmap=wcsmap,
+                           logfile=logfile,
                            procSteps=procSteps)
 
         print()
@@ -231,7 +240,7 @@ def run(configobj, wcsmap=None):
         print("", flush=True)
 
 
-    except:
+    except Exception:
         clean = False
         print(textutil.textbox(
             "ERROR:\nAstroDrizzle Version {:s} encountered a problem!  "
@@ -250,58 +259,12 @@ def run(configobj, wcsmap=None):
             del outwcs
 
 
-def help(file=None):
-    """
-    Print out syntax help for running astrodrizzle
-
-    Parameters
-    ----------
-    file : str (Default = None)
-        If given, write out help to the filename specified by this parameter
-        Any previously existing file with this name will be deleted before
-        writing out the help.
-
-    """
-    helpstr = getHelpAsString(docstring=True, show_ver = True)
-    if file is None:
-        print(helpstr)
-    else:
-        if os.path.exists(file): os.remove(file)
-        f = open(file, mode = 'w')
-        f.write(helpstr)
-        f.close()
-
-
-def getHelpAsString(docstring = False, show_ver = True):
-    """
-    return useful help from a file in the script directory called
-    __taskname__.help
-
-    """
-    install_dir = os.path.dirname(__file__)
-    taskname = util.base_taskname(__taskname__, '')
-    htmlfile = os.path.join(install_dir, 'htmlhelp', taskname + '.html')
-    helpfile = os.path.join(install_dir, taskname + '.help')
-
-    if docstring or (not docstring and not os.path.exists(htmlfile)):
-        if show_ver:
-            helpString = os.linesep + \
-                ' '.join([__taskname__, 'Version', __version__,
-                ' updated on ', __version_date__]) + 2*os.linesep
-        else:
-            helpString = ''
-        if os.path.exists(helpfile):
-            helpString += teal.getHelpFileAsString(taskname, __file__)
-        else:
-            if __doc__ is not None:
-                helpString += __doc__ + os.linesep
-    else:
-        helpString = 'file://' + htmlfile
-
-    return helpString
-
+AstroDrizzle.__doc__ = util._def_help_functions(
+    locals(), module_file=__file__, task_name=__taskname__, module_doc=__doc__
+)
 
 _fidx = 0
+
 def _dbg_dump_virtual_outputs(imgObjList):
     """ dump some helpful information.  strictly for debugging """
     global _fidx
@@ -341,5 +304,3 @@ def _dbg_dump_virtual_outputs(imgObjList):
                     log.info(str(type(FITSOBJ)))
                 log.info(vok+'\n')
     log.info('-'*80)
-
-AstroDrizzle.__doc__ = getHelpAsString(docstring = True, show_ver = False)
