@@ -174,7 +174,7 @@ class AlignmentTable:
                 hdr0 = fits.getheader(img)
                 instrume = hdr0.get('instrume')
                 if instrume.lower() == 'wfpc2' and 'detector' not in hdr0:
-                    detector = 'PC'
+                    detector = 'WFPC2'
                 else:
                     detector = hdr0.get('detector')
 
@@ -234,7 +234,6 @@ class AlignmentTable:
         for img in self.haplist:
             img.close()
 
-
     def find_alignment_sources(self, output=True, crclean=None):
         """Find observable sources in each input exposure."""
         if crclean is None:
@@ -276,7 +275,6 @@ class AlignmentTable:
             image.meta["group_id"] = self.group_id_dict["{}_{}".format(image.meta["rootname"], image.meta["chip"])]
             image.meta['num_ref_catalog'] = num_ref
 
-
     def configure_fit(self):
         # Convert input images to tweakwcs-compatible FITSWCSCorrector objects and
         # attach source catalogs to them.
@@ -1322,12 +1320,18 @@ def update_image_wcs_info(tweakwcs_output, headerlet_filenames=None, fit_label=N
         updatehdr.update_wcs(hdulist, sci_extn, item.wcs, wcsname=wcs_name, reusename=True)
         info = item.meta['fit_info']
         if info['catalog'] and info['catalog'] != '':
-            rms_ra_val = info['RMS_RA'].value if info['RMS_RA'] is not None else -1.0
-            rms_dec_val = info['RMS_DEC'].value if info['RMS_DEC'] is not None else -1.0
+            # Explicitly report the RMS values in units of mas.
+            rms_ra_val = info['RMS_RA'].mas if info['RMS_RA'] is not None else -1.0
+            rms_dec_val = info['RMS_DEC'].mas if info['RMS_DEC'] is not None else -1.0
             hdulist[sci_extn].header['RMS_RA'] = (rms_ra_val, RMS_RA_COMMENT)
             hdulist[sci_extn].header['RMS_DEC'] = (rms_dec_val, RMS_DEC_COMMENT)
-            hdulist[sci_extn].header['CRDER1'] = info['RMS_RA'].value/3600. if info['RMS_RA'] is not None else -1.0
-            hdulist[sci_extn].header['CRDER2'] = info['RMS_DEC'].value/3600. if info['RMS_DEC'] is not None else -1.0
+            # convert RMS values from units of mas to deg in order to be consistent
+            # with CUNIT keyword value, as per FITS Paper I standard.
+            # https://www.aanda.org/articles/aa/full/2002/45/aah3859/aah3859.right.html Section 2.6
+            cr1_comment = RMS_RA_COMMENT.replace('mas', 'deg')
+            cr2_comment = RMS_DEC_COMMENT.replace('mas', 'deg')
+            hdulist[sci_extn].header['CRDER1'] = (info['RMS_RA'].deg, cr1_comment) if info['RMS_RA'] is not None else -1.0
+            hdulist[sci_extn].header['CRDER2'] = (info['RMS_DEC'].deg, cr2_comment) if info['RMS_DEC'] is not None else -1.0
             hdulist[sci_extn].header['NMATCHES'] = len(info['ref_mag']) if info['ref_mag'] is not None else 0
             hdulist[sci_extn].header['FITGEOM'] = info['fitgeom'] if info['fitgeom'] is not None else 'N/A'
         else:
@@ -1442,6 +1446,7 @@ def register_photutils_function(name):
 # http://lordsabre.blogspot.ca/2017/09/matlab-normxcorr2-implemented-in-python.html    #
 ########################################################################################
 
+
 def normxcorr2(template, image, mode="full"):
     """
     Input arrays should be floating point numbers.
@@ -1484,6 +1489,7 @@ def normxcorr2(template, image, mode="full"):
 
     return out
 
+
 def compute_xcorr_offset(image, refimage, window=32):
     """Use normxcorr2 to determine sub-pixel offset between two images.
 
