@@ -567,6 +567,18 @@ def verify_guiding(filename, min_length=33):
     log.info(f"Verifying that {filename} was not affected by guiding problems.")
 
     hdu = fits.open(filename)
+    # Let's start by checking whether the header indicates any problems with
+    # the guide stars or tracking.
+    # Using .get() insures that this check gets done even if keyword is missing.
+    gs_quality = hdu[0].header.get('quality', default="").lower()
+    if 'gsfail' in gs_quality or 'tdf-down' in gs_quality:
+        hdu.close()
+        log.warning(f"Image {filename}'s GUIDING detected as: BAD.")
+        return True  # Yes, there was bad guiding...
+
+    # No guide star problems indicated in header, so let's check the
+    # data.  There are many instances where the data is compromised
+    # despite what values are found in the header.
     data = hdu[("SCI", 1)].data.copy()
     scale_data = hdu[("SCI",1)].header["bunit"].endswith('/S')
     data = np.nan_to_num(data, nan=0.0)  # just to be careful
@@ -605,9 +617,10 @@ def verify_guiding(filename, min_length=33):
     # Trying to ignore small sources (<= 4x4 pixels in size, or npixels < 17)
     #   which are either noise peaks or head-on CRs.
     segm = detect_sources(imgarr, 0, npixels=17)
-    log.debug(f'Detected {segm.nlabels} raw sources in {filename}')
-    if segm.nlabels < 2:
+    if segm is None or segm.nlabels < 2:
+        log.debug(f'Did NOT detect enough raw sources in {filename} for guiding verification.')
         return False
+    log.debug(f'Detected {segm.nlabels} raw sources in {filename} for guiding verification.')
 
     src_cat = SourceCatalog(imgarr, segm)
     # Remove likely cosmic-rays based on central_moments classification
@@ -615,6 +628,11 @@ def verify_guiding(filename, min_length=33):
     # Get the label IDs for sources flagged as CRs, IDs are 1-based not 0-based
     pt_srcs = np.where(bad_srcs == 0)[0] + 1
     segm.remove_labels(pt_srcs)
+    # If there are no sources left, this is akin to the check above where number
+    # of sources < 2, so just return False
+    if segm.nlabels == 0:
+        log.warning("After removal of suspected cosmic rays, there are no sources remaining in the image.")
+        return False
     src_cat = SourceCatalog(imgarr, segm)  # clean up source catalog now...
     num_sources = len(src_cat)
 
