@@ -34,20 +34,18 @@ Dependencies
 * ci_table.py
 """
 import glob
-import json
 import math
 import os
 import sys
 import time
 
 from astropy.io import fits as fits
-from astropy.table import Table
 import numpy
 import scipy
 import scipy.ndimage
 
-from drizzlepac.haputils import ci_table
 from stsci.tools import logutil
+from stsci.tools import fileutil
 from stwcs import wcsutil
 
 
@@ -324,6 +322,7 @@ def hla_saturation_flags(drizzled_image, flt_list, catalog_name, catalog_data, p
     """
     image_split = drizzled_image.split('/')[-1]
     channel = drizzled_image.split("_")[4].upper()
+    instrume = drizzled_image.split("_")[3].upper()
 
     if channel == 'IR':  # TODO: Test and IR case just to make sure that IR shouldn't be skipped
         return catalog_data
@@ -348,17 +347,21 @@ def hla_saturation_flags(drizzled_image, flt_list, catalog_name, catalog_data, p
     # EXTRACT DQ DATA FROM FLT IMAGE AND CREATE A LIST
     # OF "ALL" PIXEL COORDINATES WITH A FLAG VALUE OF 256
     # ----------------------------------------------------
+    # instrume: name of instrument from INSTRUME keyword used in filename
+    # Channel: detector or chip ID from instrument used for exposure
+    #          WFPC2 does not define this in the image headers,
+    #          so default values 'PC' and 'WF' are used
     if ((channel.lower() != 'wfpc2') and (channel.lower() != 'pc')):
         if channel.lower() in ['wfc', 'uvis']:
             image_ext_list = ["[sci,1]", "[sci,2]"]
         if channel.lower() in ['sbc', 'hrc']:
             image_ext_list = ["[sci,1]"]
         dq_sat_bit = 256
-    if channel.lower() == 'wfpc2':
-        image_ext_list = ["[sci,1]", "[sci,2]", "[sci,3]", "[sci,4]"]
-        dq_sat_bit = 8
-    if channel.lower() == 'pc':
-        image_ext_list = ["[sci,1]"]
+
+    if instrume.lower() == 'wfpc2':
+        numext = fileutil.countExtn(flt_list[0], extname='SCI')
+        # This accounts for readouts of only some detectors instead of all 4
+        image_ext_list = [f"[sci,{i+1}]" for i in range(numext)]
         dq_sat_bit = 8
 
     # build list of arrays
@@ -368,10 +371,13 @@ def hla_saturation_flags(drizzled_image, flt_list, catalog_name, catalog_data, p
         for ext_cnt, image_ext in enumerate(image_ext_list):
             ext_part = image_ext.split(',')[1].split(']')[0]
             try:
+                flt_data = fits.getdata(flt_image, 'DQ', int(ext_part))
+                """
                 if ((channel.lower() != 'wfpc2') and (channel.lower() != 'pc')):
                     flt_data = fits.getdata(flt_image, 'DQ', int(ext_part))
                 if ((channel.lower() == 'wfpc2') or (channel.lower() == 'pc')):
-                    flt_data = fits.getdata(flt_image.replace("_c0m", "_c1m"), 'SCI', int(ext_part))
+                   flt_data = fits.getdata(flt_image.replace("_c0m", "_c1m"), 'SCI', int(ext_part))
+                """
             except KeyError:
                 log.info(' ')
                 log.info('WARNING: There is only one set of file extensions in {}'.format(flt_image))
