@@ -64,18 +64,15 @@ EXAMPLES
 """
 import os
 import numpy as np
-from astropy.nddata import interpret_bit_flags
 
 from stsci.tools import stpyfits as fits
 from stsci.tools import parseinput, logutil
+from stsci.tools.bitmask import interpret_bit_flags
 
 from . import util
+from . import __version__
 
-__taskname__ = "drizzlepac.resetbits"
-
-# This is specifically NOT intended to match the package-wide version information.
-__version__ = '1.0.1'
-__version_date__ = '23-March-2017'
+__taskname__ = "resetbits"
 
 
 log = logutil.create_logger(__name__, level=logutil.logging.NOTSET)
@@ -185,7 +182,7 @@ def main():
 
     if (help):
         print(__doc__)
-        print("\t", __version__+'('+__version_date__+')')
+        print("\t", __version__)
     else:
         reset_dq_bits(args[0],args[1],args[2], args[3])
 
@@ -193,53 +190,6 @@ def main():
 if __name__ == "__main__":
     main()
 
-
-def help(file=None):
-    """
-    Print out syntax help for running astrodrizzle
-
-    Parameters
-    ----------
-    file : str (Default = None)
-        If given, write out help to the filename specified by this parameter
-        Any previously existing file with this name will be deleted before
-        writing out the help.
-
-    """
-    helpstr = getHelpAsString(docstring=True, show_ver = True)
-    if file is None:
-        print(helpstr)
-    else:
-        if os.path.exists(file): os.remove(file)
-        f = open(file, mode = 'w')
-        f.write(helpstr)
-        f.close()
-
-
-def getHelpAsString(docstring = False, show_ver = True):
-    """
-    return useful help from a file in the script directory called
-    __taskname__.help
-
-    """
-    install_dir = os.path.dirname(__file__)
-    taskname = util.base_taskname(__taskname__, __package__)
-    htmlfile = os.path.join(install_dir, 'htmlhelp', taskname + '.html')
-    helpfile = os.path.join(install_dir, taskname + '.help')
-
-    if docstring or (not docstring and not os.path.exists(htmlfile)):
-        if show_ver:
-            helpString = os.linesep + \
-                ' '.join([__taskname__, 'Version', __version__,
-                ' updated on ', __version_date__]) + 2*os.linesep
-        else:
-            helpString = ''
-        if os.path.exists(helpfile):
-            helpString += teal.getHelpFileAsString(taskname, __file__)
-        else:
-            if __doc__ is not None:
-                helpString += __doc__ + os.linesep
-    else:
-        helpString = 'file://' + htmlfile
-
-    return helpString
+util._def_help_functions(
+    locals(), module_file=__file__, task_name=__taskname__, module_doc=__doc__
+)
