@@ -94,6 +94,7 @@ except ImportError:
 # THIRD-PARTY
 import numpy as np
 from astropy.io import fits
+import photutils
 
 import stwcs
 from stwcs import wcsutil
@@ -121,6 +122,7 @@ from drizzlepac import wcs_functions
 # for WFPC2 support
 from drizzlepac.haputils import config_utils
 from drizzlepac import wfpc2Data
+from drizzlepac import photeq
 
 from . import __version__
 
@@ -157,14 +159,17 @@ focus_pars = {"WFC3/IR": {'sigma': 2.0, 'good_bits': 512},
               "ACS/WFC": {'sigma': 1.5, 'good_bits': 1360},
               "ACS/SBC": {'sigma': 2.0, 'good_bits': 0},
               "ACS/HRC": {'sigma': 1.5, 'good_bits': 1360},
-              "WFPC2/PC": {'sigma': 1.5, 'good_bits': 1360},
-              "WFPC2/WF": {'sigma': 1.5, 'good_bits': 1360}}
+              "WFPC2/WFPC2": {'sigma': 1.5, 'good_bits': 1360}}
 
 sub_dirs = ['OrIg_files', 'pipeline-default']
 valid_alignment_modes = ['apriori', 'aposteriori', 'default-pipeline']
 gsc240_date = '2017-10-01'
 apriori_priority = ['HSC', 'GSC', '']
 
+FILTER_NAMES = {'WFPC2': ['FILTNAM1', 'FILTNAM2'],
+                'ACS': ['FILTER1', 'FILTER2'],
+                'WFC3': ['FILTER']}
+
 
 # default marker for trailer files
 __trlmarker__ = '*** astrodrizzle Processing Version ' + __version__ + '***\n'
@@ -196,10 +201,12 @@ def process(inFile, force=False, newpath=None, num_cores=None, inmemory=True,
     init_time = time.time()
     trlmsg = "{}: Calibration pipeline processing of {} started.\n".format(init_time, inFile)
     trlmsg += __trlmarker__
-    trlmsg += "    drizzlepac version {}".format(drizzlepac.__version__)
-    trlmsg += "    tweakwcs version {}".format(tweakwcs.__version__)
-    trlmsg += "    stwcs version {}".format(stwcs.__version__)
-    trlmsg += "    numpy version {}".format(np.__version__)
+    trlmsg += "    drizzlepac version {}\n".format(drizzlepac.__version__)
+    trlmsg += "    tweakwcs version {}\n".format(tweakwcs.__version__)
+    trlmsg += "    stwcs version {}\n".format(stwcs.__version__)
+    trlmsg += "    numpy version {}\n".format(np.__version__)
+    trlmsg += "    photutils version {}\n".format(photutils.__version__)
+
     pipeline_pars = PIPELINE_PARS.copy()
     _verify = True  # Switch to control whether to verify alignment or not
     manifest_list = []
@@ -256,7 +263,7 @@ def process(inFile, force=False, newpath=None, num_cores=None, inmemory=True,
             print("ERROR: Input file - %s - does not exist." % inFilename)
             return
     except TypeError:
-        print("ERROR: Inappropriate input file.")
+        print("ERROR: Appropriate input file could not be found.")
         return
 
     # If newpath was specified, move all files to that directory for processing
@@ -283,8 +290,22 @@ def process(inFile, force=False, newpath=None, num_cores=None, inmemory=True,
             inFilename = inFilename.replace('d0m', 'c0m')
         # This returns the name of the _flt.fits file that was created
         inFilename = wfpc2Data.wfpc2_to_flt(inFilename)
-        raw_suffix = '_d0m.fits'
-        goodpix_name = 'GPIXELS'
+        if _analyze_exposure(inFilename):
+            # Update header of WFPC2 data to use latest reference
+            # files from CRDS
+            print(f"Updating distortion reference files for: {inFilename}")
+            wfpc2Data.apply_bestrefs(inFilename)
+            try:
+                photeq.photeq(files=inFilename, ref_phot_ext=3, readonly=False)
+            except Exception as err:
+                print(err)
+                print(f"WARNING: PHOTEQ was unable to run on {inFilename}")
+
+            raw_suffix = '_d0m.fits'
+            goodpix_name = 'GPIXELS'
+        else:
+            print("ERROR: Inappropriate input file.")
+            return
 
     infile_det = fits.getval(inFilename, 'detector')
     cal_ext = None
@@ -383,7 +404,6 @@ def process(inFile, force=False, newpath=None, num_cores=None, inmemory=True,
 
         _inlist = [_infile]
 
-        print("_calfiles initialized as: {}".format(_calfiles))
         if len(_calfiles) == 1 and "_raw" in _calfiles[0]:
             _verify = False
 
@@ -423,27 +443,50 @@ def process(inFile, force=False, newpath=None, num_cores=None, inmemory=True,
     for f in _calfiles+_calfiles_flc:
         processing_utils.compute_sregion(f)
 
-    # Check to see whether or not guide star failure affected these observations
-    # They would show up as images all sources streaked as if taken in SCAN mode or with a GRISM
-    # 
-    # Note: This functionality is intentionally turned off for pipeline processing at this time.
-    # However, a user may wish to invoke this functionality which is controlled by the
-    # parameter "do_verify_guiding".
-    if do_verify_guiding:
-        for fltimg in _calfiles:
-            flcimg = f.replace('_flt.fits', '_flc.fits')
-            if os.path.exists(flcimg):
-                fltimg = flcimg
-            # We want to use the FLC image, if possible, to avoid any
-            # possible detection of CTE tails as false guide-star trailing lines
-            bad_guiding = analyze.verify_guiding(fltimg)
-            if bad_guiding:
-                # Remove the affected image(s) from further processing
-                _calfiles.remove(fltimg)
-                if os.path.exists(flcimg):
-                    _calfiles_flc.remove(flcimg)
+    # If we no longer have any valid images to process due to guiding problems,
+    # set drizcorr to OMIT and finish processing gracefully.
+    if len(_calfiles) == 0:
+        dcorr = 'OMIT'
 
     if dcorr == 'PERFORM':
+        # Run updatewcs on each list of images to define pipeline default WCS
+        # based on latest distortion models
+        # Always apply latest distortion to replace pipeline-default OPUS WCS
+        # for successful creation of updated headerlets for the cases where
+        # all inputs having EXPTIME==0 (for example) or guiding is bad.
+        updatewcs.updatewcs(_calfiles, use_db=False, checkfiles=False)
+        if _calfiles_flc:
+            updatewcs.updatewcs(_calfiles_flc, use_db=False, checkfiles=False)
+
+        # Check to see whether or not guide star failure affected these observations
+        # They would show up as images all sources streaked as if taken in SCAN mode or with a GRISM
+        #
+        # Note: This functionality is intentionally turned off for pipeline processing at this time.
+        # However, a user may wish to invoke this functionality which is controlled by the
+        # parameter "do_verify_guiding".
+        if do_verify_guiding:
+            for fltimg in _calfiles:
+                flcimg = fltimg.replace('_flt.fits', '_flc.fits')
+                guide_img = flcimg if os.path.exists(flcimg) else fltimg
+                # We want to use the FLC image, if possible, to avoid any
+                # possible detection of CTE tails as false guide-star trailing lines
+                bad_guiding = analyze.verify_guiding(guide_img)
+                if bad_guiding:
+                    # If the user did not specify they wanted a drizzle product no matter what...
+                    if not force:
+                        # Remove the affected image(s) from further processing
+                        # except when user specifies they want to make a product no matter what (force=True)
+                        _calfiles.remove(fltimg)
+                        if os.path.exists(flcimg):
+                            _calfiles_flc.remove(flcimg)
+                        # If ANY input exposure has bad guiding, none of the data can be
+                        # trusted.  However, only allow alignment if the user forces the alignment.
+                    if not force_alignment:
+                        # Turn off any alignment to GAIA
+                        # After all, if one exposure has bad guiding,
+                        # none of the WCS information can be trusted.
+                        align_to_gaia = False
+                        align_with_apriori = False
 
         """
         Start updating the data and verifying that the new alignment is valid.
@@ -482,6 +525,9 @@ def process(inFile, force=False, newpath=None, num_cores=None, inmemory=True,
         _good_images = [f for f in _good_images if fits.getval(f, goodpix_name, ext=("SCI", 1)) > 0.]
         if len(_good_images) == 0:
             _good_images = _calfiles
+            # Turn off alignment to GAIA since there is no valid data in the exposure.
+            align_to_gaia = False
+
         if not wfpc2_input:
             adriz_pars = mdzhandler.getMdriztabParameters(_good_images)
         else:
@@ -501,15 +547,6 @@ def process(inFile, force=False, newpath=None, num_cores=None, inmemory=True,
             adriz_pars['combine_type'] = 'median'
             adriz_pars['combine_nhigh'] = 0
 
-        # Run updatewcs on each list of images to define pipeline default WCS
-        # based on latest distortion models
-        # Always apply latest distortion to replace pipeline-default OPUS WCS
-        # for successful creation of updated headerlets for the cases where
-        # all inputs having EXPTIME==0 (for example)
-        updatewcs.updatewcs(_calfiles, use_db=False, checkfiles=False)
-        if _calfiles_flc:
-            updatewcs.updatewcs(_calfiles_flc, use_db=False, checkfiles=False)
-
         # Integrate user-specified drizzle parameters into pipeline_pars
         _trlmsg = _timestamp('Starting alignment with bad-pixel identification')
         _trlmsg += __trlmarker__
@@ -728,7 +765,7 @@ def process(inFile, force=False, newpath=None, num_cores=None, inmemory=True,
                 try:
                     wcsname = fits.getval(fname, 'wcsname', ext=1)
                     wcstype = updatehdr.interpret_wcsname_type(wcsname)
-                    hdrname = "{}_{}-hlet.fits".format(fname.replace('.fits', ''), wcsname)
+                    hdrname = "{}_{}_hlet.fits".format(fname.replace('.fits', ''), wcsname)
                     headerlet.write_headerlet(fname, hdrname, output='flt',
                                               wcskey='PRIMARY',
                                               author="OPUS",
@@ -741,11 +778,27 @@ def process(inFile, force=False, newpath=None, num_cores=None, inmemory=True,
                 except ValueError:
                     hlet_msg += _timestamp("SKIPPED: Headerlet not created for %s \n" % fname)
                     # update trailer file to log creation of headerlet files
+
         hlet_msg += _timestamp("Writing Headerlets completed")
         ftrl = open(_trlfile, 'a')
         ftrl.write(hlet_msg)
         ftrl.close()
 
+    # Keep track of headerlet files written out to disk.
+    # Those headerlets would have been written out by 'updatewcs.updatewcs()'
+    # using a SHA256 hash for the WCSNAME portion of the headerlet filename.
+    # The headerlets written out with that naming convention are the only ones
+    # which need to be added to the manifest, since they represent the only WCS
+    # solutions which are new for the exposure and, thus, the ones which need to
+    # be saved in the astrometry database during pipeline processing.
+    for fname in _calfiles:
+        # Look for HLET files new to astrometry database written out by STWCS
+        updatewcs_hdrlets = sorted(glob.glob(f'{fname.replace(".fits", "")}_??????_hlet.fits'))
+        manifest_list.extend(updatewcs_hdrlets)
+        # Look for HLET representing the WCS used in the updated FLT/FLC file.
+        final_hdrlet = glob.glob(f'{fname.replace(".fits", "")}_hlet.fits')
+        manifest_list.extend(final_hdrlet)
+
     # add trailer file to list of output products
     manifest_list.append(_trlfile)
 
@@ -888,7 +941,7 @@ def run_driz(inlist, trlfile, calfiles, mode='default-pipeline', verify_alignmen
                 reset_mdriztab_nocr(pipeline_pars, good_bits, pipeline_pars['skysub'])
 
                 drizzlepac.astrodrizzle.AstroDrizzle(input=infile, configobj=None,
-                                                    **pipeline_pars)
+                                                     **pipeline_pars)
 
             instr_det = "{}/{}".format(fits.getval(sfile, 'instrume'), fits.getval(sfile, 'detector'))
             focus_sigma = focus_pars[instr_det]['sigma']
@@ -1209,6 +1262,7 @@ def verify_alignment(inlist, calfiles, calfiles_flc, trlfile,
 
     return focus_dicts, full_table
 
+
 def apply_headerlet(filename, headerlet_file, flcfile=None):
 
     # Use headerlet module to apply headerlet as PRIMARY WCS
@@ -1777,7 +1831,6 @@ def confirm_aposteriori_hdrlets(filename, logfile=None):
     hdrlet_extensions = wcsutil.headerlet.get_extname_extver_list(hdu, sciext='HDRLET')
     hdrlet_wcsnames = wcsutil.headerlet.get_headerlet_kw_names(hdu, 'wcsname')
 
-
     invalid_extns = []
     for wname, extname in zip(hdrlet_wcsnames, hdrlet_extensions):
         # Only evaluate a posteriori headerlets -- those with '-FIT' in WCSNAME
@@ -1787,7 +1840,9 @@ def confirm_aposteriori_hdrlets(filename, logfile=None):
             valid_dist_kws = 'A_ORDER' in hdrlet[1].header
             if not valid_ctype or not valid_dist_kws:
                 key = wcsutil.altwcs.getKeyFromName(hdu['SCI', 1].header, wname)
-                invalid_extns.append({'extname':extname, 'wcsname':wname, 'key':key})
+                # Guard against the case where the headerlet WCS is not an alternate WCS.
+                keyname = key.rstrip() if key is not None else key
+                invalid_extns.append({'extname': extname, 'wcsname': wname, 'key': keyname})
 
     hdu.close()
     # If any invalid headerlets are found, remove them from
@@ -2011,6 +2066,27 @@ def handle_remove_readonly(func, path, exc):
     else:
         raise
 
+def _analyze_exposure(filename):
+    """Evaluate whether or not this exposure should be processed at all."""
+
+    process_exposure = True
+
+    fhdu = fits.getheader(filename)
+    targname = fhdu['targname']
+    filts = fhdu['filt*']
+    instrument = fhdu['instrume']
+
+    filters = [filts[filtname].strip() for filtname in FILTER_NAMES[instrument]]
+
+    if any(x in targname for x in ['DARK', 'TUNG', 'BIAS', 'FLAT', 'DEUT', 'EARTH-CAL']):
+        print(f"ERROR: Inappropriate target with name {targname}")
+        process_exposure = False
+    if all(filter == '' for filter in filters):
+        print(f"ERROR: Inappropriate filter for exposure of {filters}")
+        process_exposure = False
+
+    return process_exposure
+
 
 # Functions to support execution from the shell.
 def main():
