@@ -8,6 +8,8 @@
 """
 import copy
 import os
+import shutil
+import glob
 
 from astropy.io import fits
 import numpy as np
@@ -17,6 +19,9 @@ from stsci.tools import fileutil, readgeis
 from .imageObject import imageObject
 from . import buildmask
 
+# Define default public CRDS server URL to use in case user does not specify one in `os.environ`
+PUBLIC_CRDS_SERVER_URL = "https://hst-crds.stsci.edu"
+
 # Translation table for any image that does not use the DQ extension of the MEF
 # for the DQ array.
 DQ_EXTNS = {'c0h': 'sdq', 'c0f': 'sci', 'c0m': 'sci'}
@@ -67,8 +72,13 @@ class WFPC2InputImage (imageObject):
         # Look for additional file with DQ array, primarily for WFPC2 data
 
         indx = self._filename.find('.fits')
+        _flt_file = False
 
-        if indx > 3:
+        if self._filename.endswith('_flt.fits'):
+            dqfile = self._filename
+            _flt_file = True
+
+        elif indx > 3:
             suffix = self._filename[indx-4:indx]
             dqfile = self._filename.replace(suffix[:3],'_c1')
 
@@ -93,7 +103,10 @@ class WFPC2InputImage (imageObject):
                         "a FITS file nor a GEIS file.".format(self._filename))
 
         if os.path.exists(dqfile):
-            dq_suffix = fits.getval(dqfile, "EXTNAME", ext=1, memmap=False)
+            if _flt_file:
+                dq_suffix = 'DQ'
+            else:
+                dq_suffix = fits.getval(dqfile, "EXTNAME", ext=1, memmap=False)
         else:
             dq_suffix = "SCI"
 
@@ -384,8 +397,9 @@ def wfpc2_to_flt(imgname):
 
     # Add keywords to be more compatible with ACS and WFC3 data
     num_sci = fileutil.countExtn(imgname)
-    det_name = 'PC' if in_sci[('sci',1)].header['detector'] == 1 else 'WF'
+    det_name = 'WFPC2'
     in_sci[0].header['DETECTOR'] = det_name
+    in_sci[0].header['PRIMESI'] = det_name
 
     if is_dq:
         # Read in existing input DQ file
@@ -429,3 +443,165 @@ def wfpc2_to_flt(imgname):
         in_dq.close()
 
     return flt_filename
+
+
+# ------------------------------------------------------
+# Function for updating headers to latest
+# reference files from CRDS
+# ------------------------------------------------------
+def apply_bestrefs(filename=None, dirname=None,
+                   uref_path=None, crds_path=None,
+                   reftypes=['idctab', 'dgeofile', 'offtab']):
+    """Update WFPC2 data to use the latest reference files from CRDS
+
+    .. note::
+        See `https://hst-crds.stsci.edu/docs/cmdline_bestrefs/
+        <https://hst-crds.stsci.edu/docs/cmdline_bestrefs/>`_
+        for details on how to configure CRDS for your local system and for definitions
+        of all the environment variables used by CRDS.
+
+    Parameters
+    ----------
+    filename : str, optional
+        Filename of input file to be updated.
+        If not specified, **all RAW and calibrated files** from the
+        current directory, or ``dirname`` directory if given, will
+        be updated.
+
+    dirname : str, optional
+        Name of directory containing WFPC2 data to be updated.
+        If not specified, current directory will be checked.
+
+    uref_path : str, optional
+        Path for ``uref`` directory on local system.
+        If not provided, the one defined in `os.environ` will be used.
+
+    crds_path : str
+        Path for the ``CRDS_PATH`` directory on local system.
+        .. warning:: If no value is specified and ``CRDS_PATH`` is not
+        already defined locally, this function will create a temporary
+        ``CRDS_PATH`` directory tree under the directory with the files
+        to be processed, populate it with the latest reference files
+        and mappings needed by CRDS, then delete it when done.
+
+    reftypes : list, optional
+        List of reference files to be updated.  If None or an empty list,
+        all reference files will be updated.
+
+    """
+    if reftypes is None:
+        reftypes = []
+
+    starting_dir = os.getcwd()
+
+    wfpc2_dir = dirname if dirname else starting_dir
+    os.chdir(wfpc2_dir)
+
+    c0m = []
+    if filename:
+        if os.path.exists(filename):
+            # User specified a single filename to process (default case)
+            d0m = [filename]
+        elif '*' in filename:
+            # User specified a wild-carded filename to use as input
+            d0m = sorted(glob.glob(filename))
+        else:
+            # Single input filename provided that could not be found
+            os.chdir(starting_dir)
+            raise ValueError(f"WFPC2 image {filename} not found in {wfpc2_dir}")
+    else:
+        # Get the list of ALL WFPC2 images from the specified directory
+        c0m = sorted(glob.glob("*c0m.fits"))
+        d0m = sorted(glob.glob("*d0m.fits"))
+
+    # Make sure we are in a directory with WFPC2 images
+    if len(d0m) == 0:
+        # Return to original starting directory
+        os.chdir(starting_dir)
+        raise ValueError(f"ERROR: No WFPC2 data in {wfpc2_dir}")
+
+    orig_crds = {'CRDS_PATH': os.environ.get('CRDS_PATH'),
+                 'uref': os.environ.get('uref'),
+                 'CRDS_SERVER_URL': os.environ.get('CRDS_SERVER_URL'),
+                 'CRDS_OBSERVATORY': os.environ.get('CRDS_OBSERVATORY')}
+
+    # Now, define what CRDS directories will be used for this update...
+    remove_local_cache = False
+    sync_refs = False if os.environ.get('CRDS_READONLY_CACHE') == '1' else True
+    if not orig_crds['CRDS_PATH']:
+        # User has not set up any local CRDS cache, so
+        # we need to define one under the current working directory
+        crds_cache = os.path.join(wfpc2_dir, 'crds_cache')
+        crds_hst_cache = os.path.join(crds_cache, 'references', 'hst')
+        crds_map_cache = os.path.join(crds_cache, 'mappings', 'hst')
+        crds_uref_path = uref_path if uref_path else os.path.join(crds_hst_cache, 'wfpc2', os.sep)
+        if not os.path.exists(crds_hst_cache):
+            os.makedirs(crds_hst_cache)
+            print(f"Creating temporary CRDS cache directory: {crds_hst_cache}")
+        if not os.path.exists(crds_map_cache):
+            os.makedirs(crds_map_cache)
+            print(f"Creating temporary CRDS MAP cache directory: {crds_map_cache}")
+        remove_local_cache = True
+    else:
+        # User has already defined a local CRDS cache, *and* it already exists, so use it.
+        if crds_path:
+            crds_cache = crds_path
+        else:
+            crds_cache = orig_crds['CRDS_PATH'] if os.path.exists(orig_crds['CRDS_PATH']) else None
+
+        crds_hst_cache = os.path.join(crds_cache, 'references', 'hst')
+        if os.path.exists(orig_crds['uref']):
+            # Use the `uref` defined by the user in their `os.environ`
+            crds_uref_path = orig_crds['uref']
+        else:
+            # User wants to explicitly use a CRDS cache they specify on input
+            # and default to a path based on CRDS_PATH if `uref_path` is not
+            # actually passed in through this function
+            crds_uref_path = uref_path if uref_path else os.path.join(crds_hst_cache, 'wfpc2', os.sep)
+
+        # `orig_crds["CRDS_PATH"]` has been defined, now verify it is valid...
+        if not os.path.exists(crds_cache):
+            # If CRDS_PATH was defined, but does not exists, raise an Exception
+            # so that the user can finish setting up their CRDS cache properly.
+            os.chdir(starting_dir)
+            raise EnvironmentError(f"CRDS_PATH was defined as {crds_cache}, but does not exist!")
+        if not os.path.exists(crds_uref_path):
+            # If CRDS_PATH was defined, but does not exists, raise an Exception
+            # so that the user can finish setting up their CRDS cache properly.
+            os.chdir(starting_dir)
+            raise EnvironmentError(f"CRDS path to `uref` was defined as {crds_uref_path}, but does not exist!")
+
+    # Now that we have confirmed we have images to update...
+    # configure CRDS for use in updating the WFPC2 data
+    os.environ['CRDS_SERVER_URL'] = orig_crds['CRDS_SERVER_URL'] if orig_crds['CRDS_SERVER_URL'] else PUBLIC_CRDS_SERVER_URL
+    os.environ['CRDS_OBSERVATORY'] = "hst"
+    os.environ['CRDS_PATH'] = crds_cache
+    os.environ['uref'] = crds_uref_path
+
+    #    os.environ['CRDS_PATH'] = "D:\data\crds_cache"
+    #    os.environ['uref'] = "D:\\data\\crds_cache\\references\\hst\\wfpc2\\"
+
+    # Only import this package if there is data to be updated
+    import crds
+
+    print(f"Running CRDS.assign_bestrefs on: {d0m} for reftypes={reftypes}")
+    # Apply bestrefs to images after downloading references to local CRDS cache
+    crds.assign_bestrefs(d0m, reftypes=reftypes, sync_references=sync_refs)
+    if len(c0m) > 0:
+        crds.assign_bestrefs(c0m, reftypes=reftypes, sync_references=sync_refs)
+
+    # clean up temp crds_cache dir, if created
+    if remove_local_cache:
+        shutil.rmtree(crds_cache)
+
+    # Now, revert os.environ to original state prior to running this function
+    for crds_key, crds_val in orig_crds.items():
+        if crds_val is None:
+            # If it was originally None, then
+            # there was no key defined originally, so delete it.
+            del os.environ[crds_key]
+        else:
+            os.environ[crds_key] = crds_val
+
+    # Return to original starting directory
+    os.chdir(starting_dir)
